@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: slony1_funcs.c,v 1.53.2.6 2009-11-27 20:31:00 cbbrowne Exp $
+ *	$Id: slony1_funcs.c,v 1.53.2.7 2010-02-16 16:57:29 cbbrowne Exp $
  * ----------------------------------------------------------------------
  */
 
@@ -475,6 +475,7 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 	if (!TransactionIdEquals(cs->currentXid, newXid))
 	{
 		int32	log_status;
+		bool isnull;
 
 		/*
 		 * Determine the currently active log table
@@ -485,7 +486,7 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 			elog(ERROR, "Slony-I: cannot determine log status");
 
 		log_status = DatumGetInt32(SPI_getbinval(SPI_tuptable->vals[0],
-									SPI_tuptable->tupdesc, 1, NULL));
+									SPI_tuptable->tupdesc, 1, &isnull));
 		SPI_freetuptable(SPI_tuptable);
 
 		switch(log_status)
