@@ -3,10 +3,10 @@
 --
 --    Version 7.3 specific part of the replication support functions.
 --
---	Copyright (c) 2003-2004, PostgreSQL Global Development Group
+--	Copyright (c) 2003-2009, PostgreSQL Global Development Group
 --	Author: Jan Wieck, Afilias USA INC.
 --
--- $Id: slony1_funcs.v73.sql,v 1.9 2005/11/11 13:53:24 wieck Exp $
+-- $Id: slony1_funcs.v73.sql,v 1.9.2.2 2009-08-17 17:39:57 devrim Exp $
 -- ----------------------------------------------------------------------
 
 -- ----------------------------------------------------------------------
@@ -102,3 +102,12 @@ as 'select 1;' language sql;
 comment on function @NAMESPACE@.pre74() is 
 'Returns 1 or 0 based on whether or not the DB is running a
 version earlier than 7.4';
+
+create or replace function @NAMESPACE@.make_function_strict (text, text) returns void as
+'
+   update "pg_catalog"."pg_proc" set proisstrict = ''t'' where 
+           proname = $1 and pronamespace = (select oid from "pg_catalog"."pg_namespace" where nspname = '_@CLUSTERNAME@') and prolang = (select oid from "pg_catalog"."pg_language" where lanname = ''c'');
+' language sql;
+
+comment on function @NAMESPACE@.make_function_strict (text, text) is
+'Equivalent to 8.1+ ALTER FUNCTION ... STRICT';
