@@ -5,7 +5,10 @@
 #include "confoptions.h"
 #include "postgres.h"
 #include "misc.h"
-
+ 
+#ifdef qsort 
+#undef qsort 
+#endif
 
 static struct config_generic **conf_variables;
 static int	size_conf_variables;
@@ -71,7 +74,7 @@ build_conf_variables(void)
 	conf_vars = (struct config_generic **) malloc(size_vars * sizeof(struct config_generic *));
 	if (conf_vars == NULL)
 	{
-		slon_log(FATAL, "malloc failed");
+		slon_log(SLON_FATAL, "malloc failed");
 		return;
 	}
 	num_vars = 0;
@@ -557,7 +560,7 @@ static struct config_int ConfigureNamesInt[] =
 		},
 		&slon_log_level,
 		4,
-		0,
+		-1,
 		4
 	},
 	{
@@ -677,6 +680,21 @@ static struct config_int ConfigureNamesInt[] =
 		1048576,					/* min val */
 		1073741824					/* max val */
 	},
+
+	{
+		{
+			(const char *)"remote_listen_timeout",		/* conf name */
+			gettext_noop("How long to wait, in seconds, before timeout when querying for remote events"),		/* short desc */
+			gettext_noop("How long to wait, in seconds, before timeout when querying for remote events"),		/* long desc */
+			SLON_C_INT			/* config type */
+		},
+		&remote_listen_timeout,			/* var name */
+		300,					/* default val */
+		30,					/* min val */
+		30000					/* max val */
+	},
+
+
 	{{0}}
 };
 
