@@ -3,17 +3,16 @@
  *
  *	Global definitions for the main replication engine.
  *
- *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
+ *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: slon.h,v 1.59 2006/03/08 18:29:10 darcyb Exp $
+ *	$Id: slon.h,v 1.59.2.5 2009-08-17 17:39:57 devrim Exp $
  *-------------------------------------------------------------------------
  */
 
 #ifndef SLON_H_INCLUDED
 #define SLON_H_INCLUDED
 
-
 #include "config.h"
 #include "misc.h"
 #include "conf-file.h"
@@ -106,6 +105,12 @@ struct SlonNode_s
 	SlonWorkMsg *message_head;
 	SlonWorkMsg *message_tail;
 
+	char	   *archive_name;
+	char	   *archive_temp;
+	char	   *archive_counter;
+	char	   *archive_timestamp;
+	FILE	   *archive_fp;
+
 	SlonNode   *prev;
 	SlonNode   *next;
 };
