@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton interface for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,10 +28,11 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -89,29 +89,32 @@
      K_REPAIR = 305,
      K_RESTART = 306,
      K_SCRIPT = 307,
-     K_SEQUENCE = 308,
-     K_SERIAL = 309,
-     K_SERVER = 310,
-     K_SET = 311,
-     K_SPOOLNODE = 312,
-     K_STORE = 313,
-     K_SUBSCRIBE = 314,
-     K_SUCCESS = 315,
-     K_SWITCH = 316,
-     K_TABLE = 317,
-     K_TIMEOUT = 318,
-     K_TRIGGER = 319,
-     K_TRUE = 320,
-     K_TRY = 321,
-     K_UNINSTALL = 322,
-     K_UNLOCK = 323,
-     K_UNSUBSCRIBE = 324,
-     K_UPDATE = 325,
-     K_YES = 326,
-     K_WAIT = 327,
-     T_IDENT = 328,
-     T_LITERAL = 329,
-     T_NUMBER = 330
+     K_SECONDS = 308,
+     K_SEQUENCE = 309,
+     K_SERIAL = 310,
+     K_SERVER = 311,
+     K_SET = 312,
+     K_SPOOLNODE = 313,
+     K_STORE = 314,
+     K_SUBSCRIBE = 315,
+     K_SUCCESS = 316,
+     K_SWITCH = 317,
+     K_TABLE = 318,
+     K_TIMEOUT = 319,
+     K_TRIGGER = 320,
+     K_TRUE = 321,
+     K_TRY = 322,
+     K_UNINSTALL = 323,
+     K_UNLOCK = 324,
+     K_UNSUBSCRIBE = 325,
+     K_UPDATE = 326,
+     K_YES = 327,
+     K_WAIT = 328,
+     K_SYNC = 329,
+     K_SLEEP = 330,
+     T_IDENT = 331,
+     T_LITERAL = 332,
+     T_NUMBER = 333
    };
 #endif
 /* Tokens.  */
@@ -165,50 +168,59 @@
 #define K_REPAIR 305
 #define K_RESTART 306
 #define K_SCRIPT 307
-#define K_SEQUENCE 308
-#define K_SERIAL 309
-#define K_SERVER 310
-#define K_SET 311
-#define K_SPOOLNODE 312
-#define K_STORE 313
-#define K_SUBSCRIBE 314
-#define K_SUCCESS 315
-#define K_SWITCH 316
-#define K_TABLE 317
-#define K_TIMEOUT 318
-#define K_TRIGGER 319
-#define K_TRUE 320
-#define K_TRY 321
-#define K_UNINSTALL 322
-#define K_UNLOCK 323
-#define K_UNSUBSCRIBE 324
-#define K_UPDATE 325
-#define K_YES 326
-#define K_WAIT 327
-#define T_IDENT 328
-#define T_LITERAL 329
-#define T_NUMBER 330
+#define K_SECONDS 308
+#define K_SEQUENCE 309
+#define K_SERIAL 310
+#define K_SERVER 311
+#define K_SET 312
+#define K_SPOOLNODE 313
+#define K_STORE 314
+#define K_SUBSCRIBE 315
+#define K_SUCCESS 316
+#define K_SWITCH 317
+#define K_TABLE 318
+#define K_TIMEOUT 319
+#define K_TRIGGER 320
+#define K_TRUE 321
+#define K_TRY 322
+#define K_UNINSTALL 323
+#define K_UNLOCK 324
+#define K_UNSUBSCRIBE 325
+#define K_UPDATE 326
+#define K_YES 327
+#define K_WAIT 328
+#define K_SYNC 329
+#define K_SLEEP 330
+#define T_IDENT 331
+#define T_LITERAL 332
+#define T_NUMBER 333
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 105 "parser.y"
 {
+
+/* Line 1676 of yacc.c  */
+#line 106 "parser.y"
+
 	int32		ival;
 	char		*str;
 	option_list	*opt_list;
 	SlonikAdmInfo	*adm_info;
 	SlonikStmt	*statement;
-}
-/* Line 1529 of yacc.c.  */
-#line 207 "y.tab.h"
-	YYSTYPE;
+
+
+
+/* Line 1676 of yacc.c  */
+#line 218 "y.tab.h"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 extern YYSTYPE yylval;
 
+
