@@ -1,4 +1,5 @@
 #!/bin/sh
+# $Id: run_test.sh,v 1.11.2.4 2009-07-28 22:20:48 cbbrowne Exp $
 
 pgbindir=${PGBINDIR:-"/usr/local/pgsql/bin"}
 numerrors=0
@@ -174,10 +175,15 @@ store_node()
       eval host=\$HOST${alias}
       eval user=\$USER${alias}
       eval port=\$PORT${alias}
+      eval logship=\$LOGSHIP${alias}
 
       if [ -n "${db}" -a "${host}" -a "${user}" -a "${port}" ]; then
         if [ ${alias} -ne ${originnode} ]; then
-          echo "STORE NODE (id=${alias}, comment='node ${alias}');" >> $mktmp/slonik.script
+          if [ "x${logship}" == "xtrue" ]; then    # Don't bother generating nodes used for log shipping
+            status "Node ${alias} is a log shipping node - no need for STORE NODE"
+          else
+            echo "STORE NODE (id=${alias}, comment='node ${alias}');" >> $mktmp/slonik.script
+         fi
         fi
         if [ ${alias} -ge ${NUMNODES} ]; then
           break;
@@ -201,6 +207,7 @@ store_path()
     eval host=\$HOST${i}
     eval user=\$USER${i}
     eval port=\$PORT${i}
+    eval logship=\$LOGSHIP${i}
 
     if [ -n "${db}" -a "${host}" -a "${user}" -a "${port}" ]; then
       j=1
@@ -210,8 +217,14 @@ store_path()
           eval bhost=\$HOST${j}
           eval buser=\$USER${j}
           eval bport=\$PORT${j}
+          eval blogship=\$LOGSHIP${j}
           if [ -n "${bdb}" -a "${bhost}" -a "${buser}" -a "${bport}" ]; then
+            if [[ "x${logship}" == "xtrue" || "x${blogship}" == "xtrue" ]]; then
+                # log shipping node - no paths need exist that involve this node
+                status "log shipping between nodes(${i}/${j}) - ls(${logship}/${blogship}) - omit STORE PATH"
+            else
 	    echo "STORE PATH (SERVER=${i}, CLIENT=${j}, CONNINFO='dbname=${db} host=${host} user=${user} port=${port}');" >> $mktmp/slonik.script
+            fi
           else
             err 3 "No conninfo"
           fi
@@ -244,9 +257,9 @@ init_origin_rdbms()
 
 	if [ -n "${db}" -a "${host}" -a "${user}" ]; then
 	  status "creating origin DB: $user -h $host -U $user -p $port $db"
-  	  $pgbindir/createdb -O $user -h $host -U $user -p $port --encoding $ENCODING $db 1> ${mktmp}/createdb.${originnode} 2> ${mktmp}/createdb.${originnode}
+  	  $pgbindir/createdb -O $user -h $host -U $user -p $port --encoding $ENCODING -T template0 $db 1> ${mktmp}/createdb.${originnode} 2> ${mktmp}/createdb.${originnode}
 	  if [ $? -ne 0 ]; then	   
-	    err 3 "An error occured trying to $pgbindir/createdb -O $user -h $host -U $user -p $port --encoding $ENCODING $db, ${mktmp}/createdb.${originnode} for details"
+	    err 3 "An error occured trying to $pgbindir/createdb -O $user -h $host -U $user -p $port --encoding $ENCODING -T template0 $db, ${mktmp}/createdb.${originnode} for details"
 	  fi
 	else
 	  err 3 "No db '${db}' or host '${host}' or user '${user}' or port '${port}' specified"
@@ -258,30 +271,6 @@ init_origin_rdbms()
 	status "done"
 }
 
-create_subscriber () {
-    alias=$1
-    originnode=${ORIGINNODE:-"1"}
-    eval odb=\$DB${originnode}
-    eval ohost=\$HOST${originnode}
-    eval ouser=\$USER${originnode}
-    eval opgbindir=\$PGBINDIR${originnode}
-    eval oport=\$PORT${originnode}
-
-    eval db=\$DB${alias}
-    eval host=\$HOST${alias}
-    eval user=\$USER${alias}
-    eval pgbindir=\$PGBINDIR${alias}
-    eval port=\$PORT${alias}
-
-    status "creating subscriber ${alias} DB: $user -h $host -U $user -p $port $db"
-    $pgbindir/createdb -O $user -h $host -U $user -p $port --encoding $ENCODING $db 1> ${mktmp}/createdb.${alias} 2> ${mktmp}/createdb.${alias}
-    status "add plpgsql to subscriber"
-    $pgbindir/createlang -h $host -U $user -p $port plpgsql $db
-    status "loading subscriber ${alias} DB from $odb"
-    $opgbindir/pg_dump -s  -h $ohost -U $ouser -p $oport $odb | $pgbindir/psql -h $host -p $port $db $user 1> ${mktmp}/init_schema.sql.${alias} 2> ${mktmp}/init_schema.sql.${alias}
-    status "done"
-}
-
 create_subscribers()
 {
         originnode=${ORIGINNODE:-"1"}
@@ -294,10 +283,22 @@ create_subscribers()
         if [ -n "${odb}" -a "${ohost}" -a "${ouser}" ]; then
           alias=1
           while : ; do
+            eval db=\$DB${alias}
+            eval host=\$HOST${alias}
+            eval user=\$USER${alias}
+	    eval pgbindir=\$PGBINDIR${alias}
+	    eval port=\$PORT${alias}
+
             if [ -n "${db}" -a "${host}" -a "${user}" -a "${port}" ]; then
               if [ ${alias} -ne ${originnode} ]; then
-	        create_subscriber ${alias}
-	      fi
+		status "creating subscriber ${alias} DB: $user -h $host -U $user -p $port $db"
+	        $pgbindir/createdb -O $user -h $host -U $user -p $port --encoding $ENCODING -T template0 $db 1> ${mktmp}/createdb.${alias} 2> ${mktmp}/createdb.${alias}
+		status "add plpgsql to subscriber"
+		$pgbindir/createlang -h $host -U $user -p $port plpgsql $db
+		status "loading subscriber ${alias} DB from $odb"
+	        $opgbindir/pg_dump -s  -h $ohost -U $ouser -p $oport $odb | $pgbindir/psql -h $host -p $port $db $user 1> ${mktmp}/init_schema.sql.${alias} 2> ${mktmp}/init_schema.sql.${alias}
+		status "done"
+              fi
               if [ ${alias} -ge ${NUMNODES} ]; then
                 break;
               else
@@ -458,8 +459,8 @@ launch_slon()
   eval cluster=\$CLUSTER1
 
   conninfo="dbname=${odb} host=${ohost} user=${ouser} port=${oport}"
-  status "launching originnode : $opgbindir/slon -s500 -g10 $cluster \"$conninfo\""
-  $opgbindir/slon -s500 -g10 $cluster "$conninfo" 1> $mktmp/slon_log.${originnode} 2> $mktmp/slon_log.${originnode} &
+  status "launching originnode : $opgbindir/slon -s500 -g10 -d2 $cluster \"$conninfo\""
+  $opgbindir/slon -s500 -g10 -d2 $cluster "$conninfo" 1> $mktmp/slon_log.${originnode} 2> $mktmp/slon_log.${originnode} &
   tmppid=$!
   tmpppid=$$
   sleep 1
@@ -481,6 +482,8 @@ launch_slon()
       eval pgbindir=\$PGBINDIR${alias}
       eval port=\$PORT${alias}
       eval cluster=\$CLUSTER1
+      eval archive=\$ARCHIVE{alias}
+      eval logship=\$LOGSHIP${alias}
 
       if [ -n "${db}" -a "${host}" -a "${user}" -a "${port}" ]; then
         unset conninfo
@@ -489,21 +492,30 @@ launch_slon()
         unset tmpppid
         eval slon${alias}_pid=
 
+        if [ "x${archive}" != "xtrue" ]; then
+          status "Creating log shipping directory - $mktmp/archive_logs_${alias}"
+          mkdir -p $mktmp/archive_logs_${alias}
+          archiveparm="-a ${mktmp}/archive_logs_${alias}"
+       fi
         conninfo="dbname=${db} host=${host} user=${user} port=${port}"
 
-        status "launching: $pgbindir/slon -s500 -g10 $cluster \"$conninfo\""
+        if [ "x${logship}" == "xtrue" ]; then
+          status "do not launch slon for node ${alias} - it receives data via log shipping"
+        else
+          status "launching: $pgbindir/slon -s500 -g10 -d2 ${archiveparm} $cluster \"$conninfo\""
 
-        $pgbindir/slon -s500 -g10 $cluster "$conninfo" 1>> $mktmp/slon_log.${alias} 2>&1 &
-        tmppid=$!
-        tmpppid=$$
-        sleep 1
+          $pgbindir/slon -s500 -g10 -d2 ${archiveparm} $cluster "$conninfo" 1>> $mktmp/slon_log.${alias} 2>&1 &
+          tmppid=$!
+          tmpppid=$$
+          sleep 1
 
-        foo=$(_check_pid slon ${tmppid} ${tmpppid})
+          foo=$(_check_pid slon ${tmppid} ${tmpppid})
 
 
-        eval slon${alias}_pid=${foo}
-        if [ -z "${foo}" -o "${tmppid}" != "${foo}" ]; then
-          warn 3 "Failed to launch slon on node ${alias} check $mktmp/slon_log.${alias} for details"
+          eval slon${alias}_pid=${foo}
+          if [ -z "${foo}" -o "${tmppid}" != "${foo}" ]; then
+            warn 3 "Failed to launch slon on node ${alias} check $mktmp/slon_log.${alias} for details"
+          fi
         fi
       fi
     fi
@@ -635,6 +647,9 @@ case `uname` in
   ;;
   Linux)
     mktmp=`mktemp -d -t slony-regress.XXXXXX`
+    if [ $MY_MKTEMP_IS_DECREPIT ] ; then
+        mktmp=`mktemp -d /tmp/slony-regress.XXXXXX`
+    fi
     if [ ! -d $mktmp ]; then
       err 3 "mktemp failed"
     fi
@@ -647,7 +662,7 @@ case `uname` in
   ;;
 esac
 
-
+echo ${testname} > ${mktmp}/TestName
 
 . $testname/generate_dml.sh
 
