@@ -27,10 +27,11 @@ generate_initdata()
   trippoint=`expr $numrows / 20`
   j=0;
   percent=0
-  status "generating ${numrows} tranactions of random data"
+  status "generating ${numrows} transactions of random data"
   percent=`expr $j \* 5`
   status "$percent %"
   GENDATA="$mktmp/generate.data"
+  echo "" > ${GENDATA}
   while : ; do
     txtalen=$(random_number 1 100)
     txta=$(random_string ${txtalen})
@@ -74,5 +75,19 @@ do_initdata()
   if [ $? -ne 0 ]; then
     warn 3 "do_initdata failed, see $mktmp/initdata.log for details"
   fi 
+  status "data load complete"
+
+  $pgbindir/psql -h $host -p $port -d $db -U $user -c "select \"_${CLUSTER1}\".generate_sync_event('1 second'::interval);" 1> $mktmp/gensync.log.1 2> $mktmp/gensync.log
+  rc=$?
+  if [ $rc -ne 0 ]; then
+      warn 3 "generate_sync_event() failed - rc=${rc} see $mktmp/gensync.log* for details"
+  fi
+  status "completed generate_sync_event() test"
+  $pgbindir/psql -h $host -p $port -d $db -U $user -c "select \"_${CLUSTER1}\".make_function_strict('xxidin', '(cstring)');" 1> $mktmp/gensync.log.1 2> $mktmp/gensync.log
+  rc=$?
+  if [ $rc -ne 0 ]; then
+      warn 3 "make_function_strict('xxidin', '(cstring)') failed - rc=${rc} see $mktmp/gensync.log* for details"
+  fi
+  status "completed make_function_strict() test"
   status "done"
 }
