@@ -1,13 +1,13 @@
 #!@@PERL@@
-# $Id: slonik_drop_table.pl,v 1.1 2006/05/30 14:52:35 cbbrowne Exp $
+# $Id: slonik_drop_table.pl,v 1.1.2.3 2009-08-17 17:39:58 devrim Exp $
 # Author: Mark Stosberg
 # Based on work by: Christopher Browne
 # Parts Copyright 2006 Summerault, LLC
-# Parts Copyright 2004 Afilias Canada
+# Parts Copyright 2004-2009 Afilias Canada
 
 use Getopt::Long;
 
-$CONFIG_FILE = '/usr/local/etc/slon_tools.conf';
+$CONFIG_FILE = '@@SYSCONFDIR@@/slon_tools.conf';
 $SHOW_USAGE  = 0;
 
 # Read command-line options
@@ -31,7 +31,7 @@ if ($SHOW_USAGE) {
     exit 0;
 }
 
-require '/usr/local/pgsql/lib//slon-tools.pm';
+require '@@PGLIBDIR@@/slon-tools.pm';
 require $CONFIG_FILE;
 
 my ($TABLE_ID,$set) = @ARGV;
@@ -40,20 +40,18 @@ unless ($TABLE_ID && $SET_ID) {
     die $USAGE;
 }
 
-$FILE="/tmp/drop_table.$$";
-open (SLONIK, ">", $FILE);
-print SLONIK genheader();
+my $slonik = '';
+
+$slonik .= genheader();
 
 # DROP TABLE
-print SLONIK "\n";
-print SLONIK "# DROP TABLE \n";
-print SLONIK "  try {\n";
-print SLONIK "    SET DROP TABLE (id = $TABLE_ID, origin = $SET_ORIGIN);\n";
-print SLONIK "  } on error {\n";
-print SLONIK "    echo 'Could not drop table $TABLE_ID for $CLUSTER_NAME!';\n";
-print SLONIK "    exit -1;\n";
-print SLONIK "  }\n";
+$slonik .= "\n";
+$slonik .= "# DROP TABLE \n";
+$slonik .= "  try {\n";
+$slonik .= "    SET DROP TABLE (id = $TABLE_ID, origin = $SET_ORIGIN);\n";
+$slonik .= "  } on error {\n";
+$slonik .= "    echo 'Could not drop table $TABLE_ID for $CLUSTER_NAME!';\n";
+$slonik .= "    exit -1;\n";
+$slonik .= "  }\n";
 
-
-close SLONIK;
-run_slonik_script($FILE);
+run_slonik_script($slonik, 'DROP TABLE');
