@@ -1,13 +1,13 @@
 #!@@PERL@@
-# $Id: slonik_print_preamble.pl,v 1.1 2006/05/30 14:52:35 cbbrowne Exp $
+# $Id: slonik_print_preamble.pl,v 1.1.2.3 2009-08-17 17:39:58 devrim Exp $
 # Author: Mark Stosberg
 # Based on work by: Christopher Browne
 # Parts Copyright 2006 Summerault, LLC
-# Parts Copyright 2004 Afilias Canada
+# Parts Copyright 2004-2009 Afilias Canada
 
 use Getopt::Long;
 
-$CONFIG_FILE = '/usr/local/etc/slon_tools.conf';
+$CONFIG_FILE = '@@SYSCONFDIR@@/slon_tools.conf';
 $SHOW_USAGE  = 0;
 
 # Read command-line options
@@ -29,11 +29,10 @@ if ($SHOW_USAGE) {
     exit 0;
 }
 
-require '/usr/local/pgsql/lib//slon-tools.pm';
+require '@@PGLIBDIR@@/slon-tools.pm';
 require $CONFIG_FILE;
 
-$FILE="/tmp/print_preamble.$$";
-open (SLONIK, ">", $FILE);
-print SLONIK genheader();
-close SLONIK;
-run_slonik_script($FILE);
+my $slonik = '';
+$slonik .= genheader();
+
+run_slonik_script($slonik, 'PRINT PREAMBLE');
